@@ -172,37 +172,37 @@ class FirstDataTests(unittest.TestCase):
         # Pre-Authorization
         #
         print "--------> Pre-Authorization"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="01",
                         cardholder_name="Daffy Duck",
                         amount="10.00",
                         cc_number="4111111111111111",
                         cc_expiry="1215")
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def tagged_pre_authorization_complete(self, sale, **kwargs):
         #
         # Tagged Pre-Authorization Completion
         #
         print "--------> Tagged Pre-Authorization Completion"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="32",
                         authorization_num=sale['authorization_num'],
                         transaction_tag=sale['transaction_tag'],
                         amount=sale['amount'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def purchase_transarmor(self, sale, **kwargs):
         #
         # Purchase w/ TransArmor
         #
         print "--------> Purchase w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="00",
                         cardholder_name="Daffy Duck",
                         transarmor_token=sale['transarmor_token'],
@@ -210,29 +210,32 @@ class FirstDataTests(unittest.TestCase):
                         credit_card_type=sale['credit_card_type'],
                         cc_expiry=sale['cc_expiry'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def void_transarmor(self, sale, **kwargs):
         #
         # Tip > 15% => Void
         #
         print "--------> Void w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="33",
                         amount="10.00",
+                        transarmor_token=sale['transarmor_token'],
+                        cc_expiry=sale['cc_expiry'],
+                        credit_card_type=sale['credit_card_type'],
                         authorization_num=sale['authorization_num'],
                         transaction_tag=sale['transaction_tag'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def pre_authorization_transarmor(self, sale, **kwargs):
         #
         # Pre-Authoization w/ TransArmor Token for $15.00
         #
         print "--------> Pre-Authorization w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="01",
                         transarmor_token=sale['transarmor_token'],
                         cardholder_name="Daffy Duck",
@@ -240,15 +243,15 @@ class FirstDataTests(unittest.TestCase):
                         credit_card_type=sale['credit_card_type'],
                         cc_expiry=sale['cc_expiry'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def tagged_pre_authorization_complete_transarmor(self, sale, **kwargs):
         #
         # Tagged Pre-Authorization Completion w/ TransArmor
         #
         print "--------> Tagged Pre-Authorization Completion w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="32",
                         cardholder_name=sale['cardholder_name'],
                         transarmor_token=sale['transarmor_token'],
@@ -258,15 +261,15 @@ class FirstDataTests(unittest.TestCase):
                         transaction_tag=sale['transaction_tag'],
                         cc_expiry=sale['cc_expiry'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def void_pre_authorization_transarmor(self, armorsale, **kwargs):
         #
         # Void a Pre-Authorization w/ TransArmor
         #
         print "--------> Void - Pre-Authorization w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="13",
                         transarmor_token=armorsale['transarmor_token'],
                         cardholder_name="Daffy Duck",
@@ -275,73 +278,73 @@ class FirstDataTests(unittest.TestCase):
                         credit_card_type=armorsale['credit_card_type'],
                         cc_expiry=armorsale['cc_expiry'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def purchase(self, **kwargs):
         #
         # Purchase
         #
         print "--------> Purchase"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="00",
                         cardholder_name="Daffy Duck",
                         cc_number="4111111111111111",
                         amount="10.00",
                         cc_expiry="1215")
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def refund(self, **kwargs):
         #
         # Refund
         #
         print "--------> Refund"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="04",
                         cardholder_name="Daffy Duck",
                         cc_number="4111111111111111",
                         amount="10.00",
                         cc_expiry="1215")
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def tagged_refund(self, sale, **kwargs):
         #
         # Tagged Refund
         #
         print "--------> Tagged Refund"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="34",
                         transaction_tag=sale['transaction_tag'],
                         amount="10.00",
                         authorization_num=sale['authorization_num'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def tagged_void(self, sale, **kwargs):
         #
         # Tagged Void
         #
         print "--------> Tagged Void"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="33",
                         transaction_tag=sale['transaction_tag'],
                         amount=sale['amount'],
                         authorization_num=sale['authorization_num'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
     def refund_transarmor(self, transarmor, **kwargs):
         #
         # Refund w/ TransArmor
         #
         print "--------> Refund w/ TransArmor"
-        defaults = dict(gateway_id=os.environ.get('gateway_id'),
-                        password=os.environ.get('password'),
+        defaults = dict(gateway_id=os.environ.get('FD_GATEWAY_ID'),
+                        password=os.environ.get('FD_PASSWORD'),
                         transaction_type="04",
                         cardholder_name="Daffy Duck",
                         transarmor_token=transarmor['transarmor_token'],
@@ -349,7 +352,7 @@ class FirstDataTests(unittest.TestCase):
                         credit_card_type=transarmor['credit_card_type'],
                         cc_expiry=transarmor['cc_expiry'])
         defaults.update(kwargs)
-        return firstdata.FirstData(os.environ.get('key'), os.environ.get('secret'), **defaults).process(test=True)
+        return firstdata.FirstData(os.environ.get('FD_KEY'), os.environ.get('FD_SECRET'), **defaults).process(test=True)
 
 
 def main():
